@@ -1,4 +1,4 @@
 import sys
 # the sys module must be reloaded otherwise setdefaultencoding is unknown
-reload(sys)
+reload(sys)  # noqa: F821
 sys.setdefaultencoding('utf8')
